pub fn watch(path: impl AsRef<Path>) -> Result<SWatcher>Expand description
A simplified watcher that monitors a path (file or directory) and returns an SWatcher object with a
standard mpsc Receiver for a Vec<SEvent>.
Each SEvent contains one spath and one simplified event kind (SEventKind).
This will ignore any path that cannot be converted to a string (i.e., it will only trigger events if the path is valid UTF-8)